﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Printing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;


namespace SaveToPDF
{
	public partial class Form1 : Form
	{
		public Form1()
		{
			InitializeComponent();
			tbPath.Text = "C:\\Test.pdf";
		}

		public void TestPieChart(string reportName)
		{
			PrintDocument printDoc = new PrintDocument();
			printDoc.PrintController = new PdfPrintController(reportName);

			printDoc.Print();
		}

		private void OnFormPaint(object sender, PaintEventArgs e)
		{
			//On Screen - Correct
			DrawPieChart.Draw(e.Graphics);
		}

		private void OnSaveToPDFClick(object sender, EventArgs e)
		{
			TestPieChart(tbPath.Text);
		}

		private void OnSelectPathClick(object sender, EventArgs e)
		{
			SaveFileDialog dialog = new SaveFileDialog();
			dialog.Filter = "PDF files (*.pdf)|*.pdf";

			if(dialog.ShowDialog() == DialogResult.OK)
			{
				tbPath.Text = dialog.FileName;
			}
		}
	}

	internal class PdfPrintController : PrintController
	{
		public PdfPrintController(string reportName)
			: base()
		{
			this.reportName = reportName;
		}

		public override void OnStartPrint(PrintDocument document, PrintEventArgs e)
		{
			pdfReport = new Infragistics.Documents.Reports.Report.Report();
			var tempReport = new Infragistics.Documents.Reports.Report.Report();
			var tempSection = tempReport.AddSection();
			document.DefaultPageSettings.PaperSize = new PaperSize(tempSection.PageSize.Name, (int)(tempSection.PageSize.Width * 100 / 72), (int)(tempSection.PageSize.Height * 100 / 72));
		}
		public override Graphics OnStartPage(PrintDocument document, PrintPageEventArgs e)
		{
			Infragistics.Documents.Reports.Report.Section.ISection section = pdfReport.AddSection();
			Infragistics.Documents.Reports.Report.ISite site = section.AddSite();
			Infragistics.Documents.Reports.Report.ICanvas canvas = site.AddCanvas(0F, 0F);
			Graphics ret = canvas.CreateGraphics();
			ret.ScaleTransform(.72f, .72f);

			DrawPieChart.Draw(ret);			

			return ret;
		}

		public override void OnEndPrint(PrintDocument document, PrintEventArgs e)
		{
			pdfReport.Publish(reportName, Infragistics.Documents.Reports.Report.FileFormat.PDF);
		}

		private string reportName;
		private Infragistics.Documents.Reports.Report.Report pdfReport;
	}

	public static class DrawPieChart
	{
		public static void Draw(Graphics g)
		{
			Rectangle gradientRect = new Rectangle(50, 50, 300, 300);
			
			List<Brush> colors = new List<Brush>() { Brushes.Gold, Brushes.Gray, Brushes.Black, Brushes.Green };
			List<Pen> pens = new List<Pen>() { Pens.Gold, Pens.Gray, Pens.Black, Pens.Green };

			//List<float> startAngles = new List<float>() { 0, 93.63103f, 185.00589f, 273.2785f };
			//List<float> widthAngles = new List<float>() { 93.63103f, 91.374855f, 88.27262f, 86.72151f };

			List<int> startAngles = new List<int>() { 0, 90, 180, 270 };
			List<int> widthAngles = new List<int>() { 90, 90, 90, 90 };

			for(int i = 0; i < colors.Count; i++)
			{
				g.FillPie(colors[i], gradientRect, startAngles[i], widthAngles[i]);
			}
		}
	}

}
